@@ -71,7 +71,7 @@ let configure gen =
 			cl.cl_ordered_fields <- fields;
 
 			List.iter (fun cf ->
-				match field_access gen (TInst(cl,List.map snd cl.cl_params)) cf.cf_name with
+				match field_access gen (TInst(cl,extract_param_types cl.cl_params)) cf.cf_name with
 				| FNotFound | FDynamicField _ ->
 					cl.cl_ordered_fields <- cf :: cl.cl_ordered_fields;
 					cl.cl_fields <- PMap.add cf.cf_name cf cl.cl_fields
