@@ -367,7 +367,11 @@ module Pattern = struct
 			| ECall(e1,el) ->
 				let e1 = type_expr ctx e1 (WithType.with_type t) in
 				begin match e1.eexpr,follow e1.etype with
-					| TField(_, FEnum(en,ef)),TFun(_,TEnum(_,tl)) ->
+					| TField(_, FEnum(en,ef)),TFun(_,tr) ->
+						let tl = match follow tr with
+							| TEnum(_,tl) -> tl
+							| _ -> fail()
+						in
 						let map = apply_params en.e_params tl in
 						let monos = Monomorph.spawn_constrained_monos map ef.ef_params in
 						let map t = map (apply_params ef.ef_params monos t) in
@@ -476,9 +480,14 @@ module Pattern = struct
 				let is_matchable cf =
 					match cf.cf_kind with Method _ -> false | _ -> true
 				in
+				(* TODO: This needs a better check, but it's not obvious how to approach this. See #11433 *)
+				let is_probably_pos cf = match cf.cf_name with
+					| "pos" | "posPath" | "namePos" -> true
+					| _ -> false
+				in
 				let patterns,fields = List.fold_left (fun (patterns,fields) (cf,t) ->
 					try
-						if pctx.in_reification && cf.cf_name = "pos" then raise Not_found;
+						if pctx.in_reification && is_probably_pos cf then raise Not_found;
 						let e1 = Expr.field_assoc cf.cf_name fl in
 						make pctx false t e1 :: patterns,cf.cf_name :: fields
 					with Not_found ->
@@ -548,7 +557,7 @@ module Pattern = struct
 				ignore(TyperDisplay.handle_edisplay ctx e (display_mode()) MGet (WithType.with_type t));
 				pat
 			| EMeta((Meta.StoredTypedExpr,_,_),e1) ->
-				let e1 = MacroContext.type_stored_expr ctx e1 in
+				let e1 = TyperBase.type_stored_expr ctx e1 in
 				loop (TExprToExpr.convert_expr e1)
 			| _ ->
 				fail()
